@@ -1,5 +1,5 @@
 package DBICx::Shortcuts;
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use strict;
 use warnings;
@@ -8,10 +8,11 @@ use Carp qw( croak );
 my %schemas;
 
 sub setup {
-  my ($class, $schema_class) = @_;
+  my ($class, $schema_class, @methods) = @_;
 
   eval "require $schema_class";
   die if $@;
+  local $ENV{DBIC_NO_VERSION_CHECK} = 1;
   my $schema = $schema_class->connect;
   
   SOURCE: for my $source ($schema->sources) {
@@ -39,6 +40,12 @@ sub setup {
     };
   }
   
+  ## Enable set of schema shortcuts
+  for my $meth (@methods) {
+    no strict 'refs';
+    *{__PACKAGE__ . "::$meth"} = sub { return shift->schema->$meth(@_) };
+  }
+
   $schemas{$class} = { class => $schema_class };
   
   return;
@@ -75,7 +82,7 @@ DBICx::Shortcuts - Setup a class with shortcut methods to the sources of a DBIx:
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -84,6 +91,9 @@ version 0.004
   
   __PACKAGE__->setup('Class::Of::Your::Schema');
   
+  ## Alternate version, this one import txn_do from DBIx::Class::Schema
+  ## __PACKAGE__->setup('Class::Of::Your::Schema', 'txn_do');
+  
   sub connect_info {
     ## return DBIx::Class::Schema::connect() arguments
     return ('dbi:SQLite:test.db', undef, undef, {AutoCommit => 1});
@@ -144,10 +154,16 @@ and have it return all the required connect() parameters.
 
     package MyShortcutsClass;
     __PACKAGE__->setup('MySchemaClass');
+    ## or
+    __PACKAGE__->setup('MySchemaClass', 'txn_do', 'storage', $other_methods);
 
 The L</setup()> accepts your schema class as a parameter, loads it, and
 creates a shortcut method for each source found inside.
 
+Optionally you can follow with a list of methods that you want to create
+as shortcuts to the same named method in
+L<DBIx::Class::Schema|DBIx::Class::Schema>.
+
 You can control some aspects of the shortcut creation using the
 <source_info()|DBIx::Class::ResultSource/source_info> ResultSource metadata hashref.
 The following keys are supported:
