@@ -1,8 +1,8 @@
 package S1;
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 use parent 'DBICx::Shortcuts';
 
-__PACKAGE__->setup('Schema');
+__PACKAGE__->setup('Schema', 'txn_do', 'storage');
 
 sub connect_info {}
 
